# generated by datamodel-codegen:
#   filename:  enums/channels.json
#   timestamp: 2025-11-22T15:23:24+00:00

from __future__ import annotations

from enum import Enum


class AdvertisingChannels(Enum):
    display = 'display'
    video = 'video'
    audio = 'audio'
    native = 'native'
    dooh = 'dooh'
    ctv = 'ctv'
    podcast = 'podcast'
    retail = 'retail'
    social = 'social'
