# generated by datamodel-codegen:
#   filename:  core/dimensions.json
#   timestamp: 2025-11-22T19:16:02+00:00

from __future__ import annotations

from typing import Annotated

from adcp.types.base import AdCPBaseModel
from pydantic import ConfigDict, Field


class Dimensions(AdCPBaseModel):
    model_config = ConfigDict(
        extra='forbid',
    )
    height: Annotated[int, Field(description='Height in pixels', ge=1)]
    width: Annotated[int, Field(description='Width in pixels', ge=1)]
