"""INTERNAL: Consolidated generated types.

DO NOT import from this module directly.
Use 'from adcp import Type' or 'from adcp.types.stable import Type' instead.

This module consolidates all generated types from generated_poc/ into a single
namespace for convenience. The leading underscore signals this is private API.

Auto-generated by datamodel-code-generator from JSON schemas.
DO NOT EDIT MANUALLY.

Generated from: https://github.com/adcontextprotocol/adcp/tree/main/schemas
Generation date: 2025-11-22 21:45:32 UTC
"""
# ruff: noqa: E501, I001
from __future__ import annotations

# Import all types from generated_poc modules
from adcp.types.generated_poc.adagents import AuthorizedAgents, AuthorizedAgents1, AuthorizedAgents2, AuthorizedAgents3, AuthorizedSalesAgents, AuthorizedSalesAgents1, AuthorizedSalesAgents2, Contact, Tags
from adcp.types.generated_poc.core.activation_key import ActivationKey1, ActivationKey2
from adcp.types.generated_poc.core.assets.audio_asset import AudioAsset
from adcp.types.generated_poc.core.assets.css_asset import CssAsset
from adcp.types.generated_poc.core.assets.daast_asset import DaastAsset1, DaastAsset2
from adcp.types.generated_poc.core.assets.html_asset import HtmlAsset
from adcp.types.generated_poc.core.assets.image_asset import ImageAsset
from adcp.types.generated_poc.core.assets.javascript_asset import JavascriptAsset
from adcp.types.generated_poc.core.assets.text_asset import TextAsset
from adcp.types.generated_poc.core.assets.url_asset import UrlAsset
from adcp.types.generated_poc.core.assets.vast_asset import VastAsset1, VastAsset2
from adcp.types.generated_poc.core.assets.video_asset import VideoAsset
from adcp.types.generated_poc.core.assets.webhook_asset import Security, WebhookAsset
from adcp.types.generated_poc.core.brand_manifest import Asset, BrandManifest, Colors, Disclaimer, FeedFormat, Fonts, Logo, Metadata, ProductCatalog, UpdateFrequency
from adcp.types.generated_poc.core.context import ContextObject
from adcp.types.generated_poc.core.creative_asset import CreativeAsset, Input
from adcp.types.generated_poc.core.creative_assignment import CreativeAssignment
from adcp.types.generated_poc.core.creative_filters import CreativeFilters
from adcp.types.generated_poc.core.creative_manifest import CreativeManifest
from adcp.types.generated_poc.core.creative_policy import CreativePolicy
from adcp.types.generated_poc.core.delivery_metrics import DeliveryMetrics, DoohMetrics, QuartileData, VenueBreakdownItem
from adcp.types.generated_poc.core.deployment import Deployment1, Deployment2
from adcp.types.generated_poc.core.destination import Destination1, Destination2
from adcp.types.generated_poc.core.dimensions import Dimensions
from adcp.types.generated_poc.core.error import Error
from adcp.types.generated_poc.core.ext import ExtensionObject
from adcp.types.generated_poc.core.format import AssetsRequired, AssetsRequired1, Dimensions2, Format, FormatCard, FormatCardDetailed, Renders, Renders1, Responsive
from adcp.types.generated_poc.core.format_id import FormatId
from adcp.types.generated_poc.core.frequency_cap import FrequencyCap
from adcp.types.generated_poc.core.measurement import Measurement
from adcp.types.generated_poc.core.media_buy import MediaBuy
from adcp.types.generated_poc.core.performance_feedback import MeasurementPeriod, PerformanceFeedback, Status
from adcp.types.generated_poc.core.placement import Placement
from adcp.types.generated_poc.core.product import DeliveryMeasurement, Product, ProductCard, ProductCardDetailed
from adcp.types.generated_poc.core.product_filters import BudgetRange, BudgetRange1, Country, ProductFilters
from adcp.types.generated_poc.core.promoted_offerings import AssetSelectors, AssetType, Offering, PromotedOfferings
from adcp.types.generated_poc.core.promoted_products import PromotedProducts
from adcp.types.generated_poc.core.property import Identifier, Property
from adcp.types.generated_poc.core.property_id import PropertyId
from adcp.types.generated_poc.core.property_tag import PropertyTag
from adcp.types.generated_poc.core.protocol_envelope import ProtocolEnvelope
from adcp.types.generated_poc.core.publisher_property_selector import PublisherPropertySelector1, PublisherPropertySelector2, PublisherPropertySelector3
from adcp.types.generated_poc.core.push_notification_config import Authentication, PushNotificationConfig
from adcp.types.generated_poc.core.reporting_capabilities import ReportingCapabilities
from adcp.types.generated_poc.core.response import ProtocolResponse
from adcp.types.generated_poc.core.signal_filters import SignalFilters
from adcp.types.generated_poc.core.sub_asset import SubAsset1, SubAsset2
from adcp.types.generated_poc.core.targeting import GeoCountryAnyOfItem, TargetingOverlay
from adcp.types.generated_poc.core.webhook_payload import Progress, WebhookPayload
from adcp.types.generated_poc.creative.list_creative_formats_request import ListCreativeFormatsRequestCreativeAgent, Type
from adcp.types.generated_poc.creative.list_creative_formats_response import CreativeAgent, ListCreativeFormatsResponseCreativeAgent
from adcp.types.generated_poc.creative.preview_creative_request import Input2, PreviewCreativeRequest, PreviewCreativeRequest1, PreviewCreativeRequest2, Request
from adcp.types.generated_poc.creative.preview_creative_response import Input4, Preview, Preview1, Preview2, PreviewCreativeResponse, PreviewCreativeResponse1, PreviewCreativeResponse2, Response, Response1, Results, Results1
from adcp.types.generated_poc.creative.preview_render import Embedding, PreviewRender, PreviewRender1, PreviewRender2, PreviewRender3
from adcp.types.generated_poc.enums.adcp_domain import AdcpDomain
from adcp.types.generated_poc.enums.asset_content_type import AssetContentType
from adcp.types.generated_poc.enums.auth_scheme import AuthenticationScheme
from adcp.types.generated_poc.enums.available_metric import AvailableMetric
from adcp.types.generated_poc.enums.channels import AdvertisingChannels
from adcp.types.generated_poc.enums.co_branding_requirement import CoBrandingRequirement
from adcp.types.generated_poc.enums.creative_action import CreativeAction
from adcp.types.generated_poc.enums.creative_agent_capability import CreativeAgentCapability
from adcp.types.generated_poc.enums.creative_sort_field import CreativeSortField
from adcp.types.generated_poc.enums.creative_status import CreativeStatus
from adcp.types.generated_poc.enums.daast_tracking_event import DaastTrackingEvent
from adcp.types.generated_poc.enums.daast_version import DaastVersion
from adcp.types.generated_poc.enums.delivery_type import DeliveryType
from adcp.types.generated_poc.enums.dimension_unit import DimensionUnit
from adcp.types.generated_poc.enums.feedback_source import FeedbackSource
from adcp.types.generated_poc.enums.format_category import FormatCategory
from adcp.types.generated_poc.enums.format_id_parameter import FormatIdParameter
from adcp.types.generated_poc.enums.frequency_cap_scope import FrequencyCapScope
from adcp.types.generated_poc.enums.history_entry_type import HistoryEntryType
from adcp.types.generated_poc.enums.http_method import HttpMethod
from adcp.types.generated_poc.enums.identifier_types import PropertyIdentifierTypes
from adcp.types.generated_poc.enums.javascript_module_type import JavascriptModuleType
from adcp.types.generated_poc.enums.landing_page_requirement import LandingPageRequirement
from adcp.types.generated_poc.enums.markdown_flavor import MarkdownFlavor
from adcp.types.generated_poc.enums.media_buy_status import MediaBuyStatus
from adcp.types.generated_poc.enums.metric_type import MetricType
from adcp.types.generated_poc.enums.notification_type import NotificationType
from adcp.types.generated_poc.enums.pacing import Pacing
from adcp.types.generated_poc.enums.preview_output_format import PreviewOutputFormat
from adcp.types.generated_poc.enums.pricing_model import PricingModel
from adcp.types.generated_poc.enums.property_type import PropertyType
from adcp.types.generated_poc.enums.publisher_identifier_types import PublisherIdentifierTypes
from adcp.types.generated_poc.enums.reporting_frequency import ReportingFrequency
from adcp.types.generated_poc.enums.signal_catalog_type import SignalCatalogType
from adcp.types.generated_poc.enums.sort_direction import SortDirection
from adcp.types.generated_poc.enums.standard_format_ids import StandardFormatIds
from adcp.types.generated_poc.enums.task_status import TaskStatus
from adcp.types.generated_poc.enums.task_type import TaskType
from adcp.types.generated_poc.enums.url_asset_type import UrlAssetType
from adcp.types.generated_poc.enums.validation_mode import ValidationMode
from adcp.types.generated_poc.enums.vast_tracking_event import VastTrackingEvent
from adcp.types.generated_poc.enums.vast_version import VastVersion
from adcp.types.generated_poc.enums.webhook_response_type import WebhookResponseType
from adcp.types.generated_poc.enums.webhook_security_method import WebhookSecurityMethod
from adcp.types.generated_poc.media_buy.build_creative_request import BuildCreativeRequest
from adcp.types.generated_poc.media_buy.build_creative_response import BuildCreativeResponse, BuildCreativeResponse1, BuildCreativeResponse2
from adcp.types.generated_poc.media_buy.create_media_buy_request import CreateMediaBuyRequest, ReportingWebhook, RequestedMetric
from adcp.types.generated_poc.media_buy.create_media_buy_response import CreateMediaBuyResponse, CreateMediaBuyResponse1, CreateMediaBuyResponse2
from adcp.types.generated_poc.media_buy.get_media_buy_delivery_request import GetMediaBuyDeliveryRequest
from adcp.types.generated_poc.media_buy.get_media_buy_delivery_response import AggregatedTotals, ByPackageItem, DailyBreakdownItem, DeliveryStatus, GetMediaBuyDeliveryResponse, MediaBuyDelivery, ReportingPeriod, Totals
from adcp.types.generated_poc.media_buy.get_products_request import GetProductsRequest
from adcp.types.generated_poc.media_buy.get_products_response import GetProductsResponse
from adcp.types.generated_poc.media_buy.list_authorized_properties_request import ListAuthorizedPropertiesRequest, PublisherDomain
from adcp.types.generated_poc.media_buy.list_authorized_properties_response import ListAuthorizedPropertiesResponse, PrimaryCountry
from adcp.types.generated_poc.media_buy.list_creative_formats_request import ListCreativeFormatsRequest
from adcp.types.generated_poc.media_buy.list_creative_formats_response import ListCreativeFormatsResponse
from adcp.types.generated_poc.media_buy.list_creatives_request import FieldModel, ListCreativesRequest, Pagination, Sort
from adcp.types.generated_poc.media_buy.list_creatives_response import AssignedPackage, Assignments, Creative, ListCreativesResponse, Performance, QuerySummary, SortApplied, StatusSummary
from adcp.types.generated_poc.media_buy.package_request import PackageRequest
from adcp.types.generated_poc.media_buy.provide_performance_feedback_request import ProvidePerformanceFeedbackRequest, ProvidePerformanceFeedbackRequest1, ProvidePerformanceFeedbackRequest2
from adcp.types.generated_poc.media_buy.provide_performance_feedback_response import ProvidePerformanceFeedbackResponse, ProvidePerformanceFeedbackResponse1, ProvidePerformanceFeedbackResponse2
from adcp.types.generated_poc.media_buy.sync_creatives_request import SyncCreativesRequest
from adcp.types.generated_poc.media_buy.sync_creatives_response import SyncCreativesResponse, SyncCreativesResponse1, SyncCreativesResponse2
from adcp.types.generated_poc.media_buy.update_media_buy_request import Packages, Packages1, Packages2, Packages3, UpdateMediaBuyRequest, UpdateMediaBuyRequest1, UpdateMediaBuyRequest2
from adcp.types.generated_poc.media_buy.update_media_buy_response import UpdateMediaBuyResponse, UpdateMediaBuyResponse1, UpdateMediaBuyResponse2
from adcp.types.generated_poc.pricing_options.cpc_option import CpcPricingOption
from adcp.types.generated_poc.pricing_options.cpcv_option import CpcvPricingOption
from adcp.types.generated_poc.pricing_options.cpm_auction_option import CpmAuctionPricingOption, PriceGuidance
from adcp.types.generated_poc.pricing_options.cpm_fixed_option import CpmFixedRatePricingOption
from adcp.types.generated_poc.pricing_options.cpp_option import CppPricingOption, Parameters
from adcp.types.generated_poc.pricing_options.cpv_option import CpvPricingOption, ViewThreshold, ViewThreshold1
from adcp.types.generated_poc.pricing_options.flat_rate_option import FlatRatePricingOption
from adcp.types.generated_poc.pricing_options.vcpm_auction_option import VcpmAuctionPricingOption
from adcp.types.generated_poc.pricing_options.vcpm_fixed_option import VcpmFixedRatePricingOption
from adcp.types.generated_poc.protocols.adcp_extension import AdcpAgentCardExtension, ProtocolsSupportedEnum
from adcp.types.generated_poc.signals.activate_signal_request import ActivateSignalRequest
from adcp.types.generated_poc.signals.activate_signal_response import ActivateSignalResponse, ActivateSignalResponse1, ActivateSignalResponse2
from adcp.types.generated_poc.signals.get_signals_request import DeliverTo, GetSignalsRequest
from adcp.types.generated_poc.signals.get_signals_response import GetSignalsResponse, Pricing, Signal

# Special imports for name collisions (qualified names for types defined in multiple modules)
from adcp.types.generated_poc.core.package import Package as _PackageFromPackage

# Backward compatibility aliases for renamed types
Channels = AdvertisingChannels

# Explicit exports
__all__ = [
    "ActivateSignalRequest", "ActivateSignalResponse", "ActivateSignalResponse1",
    "ActivateSignalResponse2", "ActivationKey1", "ActivationKey2", "AdcpAgentCardExtension",
    "AdcpDomain", "AdvertisingChannels", "AggregatedTotals", "Asset", "AssetContentType",
    "AssetSelectors", "AssetType", "AssetsRequired", "AssetsRequired1", "AssignedPackage",
    "Assignments", "AudioAsset", "Authentication", "AuthenticationScheme", "AuthorizedAgents",
    "AuthorizedAgents1", "AuthorizedAgents2", "AuthorizedAgents3", "AuthorizedSalesAgents",
    "AuthorizedSalesAgents1", "AuthorizedSalesAgents2", "AvailableMetric", "BrandManifest",
    "BudgetRange", "BudgetRange1", "BuildCreativeRequest", "BuildCreativeResponse",
    "BuildCreativeResponse1", "BuildCreativeResponse2", "ByPackageItem", "Channels",
    "CoBrandingRequirement", "Colors", "Contact", "ContextObject", "Country", "CpcPricingOption",
    "CpcvPricingOption", "CpmAuctionPricingOption", "CpmFixedRatePricingOption",
    "CppPricingOption", "CpvPricingOption", "CreateMediaBuyRequest", "CreateMediaBuyResponse",
    "CreateMediaBuyResponse1", "CreateMediaBuyResponse2", "Creative", "CreativeAction",
    "CreativeAgent", "CreativeAgentCapability", "CreativeAsset", "CreativeAssignment",
    "CreativeFilters", "CreativeManifest", "CreativePolicy", "CreativeSortField", "CreativeStatus",
    "CssAsset", "DaastAsset1", "DaastAsset2", "DaastTrackingEvent", "DaastVersion",
    "DailyBreakdownItem", "DeliverTo", "DeliveryMeasurement", "DeliveryMetrics", "DeliveryStatus",
    "DeliveryType", "Deployment1", "Deployment2", "Destination1", "Destination2", "DimensionUnit",
    "Dimensions", "Dimensions2", "Disclaimer", "DoohMetrics", "Embedding", "Error",
    "ExtensionObject", "FeedFormat", "FeedbackSource", "FieldModel", "FlatRatePricingOption",
    "Fonts", "Format", "FormatCard", "FormatCardDetailed", "FormatCategory", "FormatId",
    "FormatIdParameter", "FrequencyCap", "FrequencyCapScope", "GeoCountryAnyOfItem",
    "GetMediaBuyDeliveryRequest", "GetMediaBuyDeliveryResponse", "GetProductsRequest",
    "GetProductsResponse", "GetSignalsRequest", "GetSignalsResponse", "HistoryEntryType",
    "HtmlAsset", "HttpMethod", "Identifier", "ImageAsset", "Input", "Input2", "Input4",
    "JavascriptAsset", "JavascriptModuleType", "LandingPageRequirement",
    "ListAuthorizedPropertiesRequest", "ListAuthorizedPropertiesResponse",
    "ListCreativeFormatsRequest", "ListCreativeFormatsRequestCreativeAgent",
    "ListCreativeFormatsResponse", "ListCreativeFormatsResponseCreativeAgent",
    "ListCreativesRequest", "ListCreativesResponse", "Logo", "MarkdownFlavor", "Measurement",
    "MeasurementPeriod", "MediaBuy", "MediaBuyDelivery", "MediaBuyStatus", "Metadata",
    "MetricType", "NotificationType", "Offering", "Pacing", "PackageRequest", "Packages",
    "Packages1", "Packages2", "Packages3", "Pagination", "Parameters", "Performance",
    "PerformanceFeedback", "Placement", "Preview", "Preview1", "Preview2",
    "PreviewCreativeRequest", "PreviewCreativeRequest1", "PreviewCreativeRequest2",
    "PreviewCreativeResponse", "PreviewCreativeResponse1", "PreviewCreativeResponse2",
    "PreviewOutputFormat", "PreviewRender", "PreviewRender1", "PreviewRender2", "PreviewRender3",
    "PriceGuidance", "Pricing", "PricingModel", "PrimaryCountry", "Product", "ProductCard",
    "ProductCardDetailed", "ProductCatalog", "ProductFilters", "Progress", "PromotedOfferings",
    "PromotedProducts", "Property", "PropertyId", "PropertyIdentifierTypes", "PropertyTag",
    "PropertyType", "ProtocolEnvelope", "ProtocolResponse", "ProtocolsSupportedEnum",
    "ProvidePerformanceFeedbackRequest", "ProvidePerformanceFeedbackRequest1",
    "ProvidePerformanceFeedbackRequest2", "ProvidePerformanceFeedbackResponse",
    "ProvidePerformanceFeedbackResponse1", "ProvidePerformanceFeedbackResponse2",
    "PublisherDomain", "PublisherIdentifierTypes", "PublisherPropertySelector1",
    "PublisherPropertySelector2", "PublisherPropertySelector3", "PushNotificationConfig",
    "QuartileData", "QuerySummary", "Renders", "Renders1", "ReportingCapabilities",
    "ReportingFrequency", "ReportingPeriod", "ReportingWebhook", "Request", "RequestedMetric",
    "Response", "Response1", "Responsive", "Results", "Results1", "Security", "Signal",
    "SignalCatalogType", "SignalFilters", "Sort", "SortApplied", "SortDirection",
    "StandardFormatIds", "Status", "StatusSummary", "SubAsset1", "SubAsset2",
    "SyncCreativesRequest", "SyncCreativesResponse", "SyncCreativesResponse1",
    "SyncCreativesResponse2", "Tags", "TargetingOverlay", "TaskStatus", "TaskType", "TextAsset",
    "Totals", "Type", "UpdateFrequency", "UpdateMediaBuyRequest", "UpdateMediaBuyRequest1",
    "UpdateMediaBuyRequest2", "UpdateMediaBuyResponse", "UpdateMediaBuyResponse1",
    "UpdateMediaBuyResponse2", "UrlAsset", "UrlAssetType", "ValidationMode", "VastAsset1",
    "VastAsset2", "VastTrackingEvent", "VastVersion", "VcpmAuctionPricingOption",
    "VcpmFixedRatePricingOption", "VenueBreakdownItem", "VideoAsset", "ViewThreshold",
    "ViewThreshold1", "WebhookAsset", "WebhookPayload", "WebhookResponseType",
    "WebhookSecurityMethod", "_PackageFromPackage"
]


# Rebuild models with forward references
# This must happen AFTER all imports to resolve module-qualified type references
# like brand_manifest.BrandManifest used in generated code

# Import individual modules needed for rebuilding
from adcp.types import generated_poc

# Rebuild models that reference other models via forward refs
BrandManifest.model_rebuild()
PromotedOfferings.model_rebuild()
CreativeManifest.model_rebuild()
PreviewCreativeRequest1.model_rebuild()
PreviewCreativeRequest2.model_rebuild()
PreviewCreativeRequest.model_rebuild()
