# generated by datamodel-codegen:
#   filename:  core/assets/image_asset.json
#   timestamp: 2025-11-22T19:16:02+00:00

from __future__ import annotations

from typing import Annotated

from pydantic import AnyUrl, Field

from ..dimensions import Dimensions


class ImageAsset(Dimensions):
    alt_text: Annotated[str | None, Field(description='Alternative text for accessibility')] = None
    format: Annotated[
        str | None, Field(description='Image file format (jpg, png, gif, webp, etc.)')
    ] = None
    url: Annotated[AnyUrl, Field(description='URL to the image asset')]
