# generated by datamodel-codegen:
#   filename:  enums/available_metric.json
#   timestamp: 2025-11-22T15:23:24+00:00

from __future__ import annotations

from enum import Enum


class AvailableMetric(Enum):
    impressions = 'impressions'
    spend = 'spend'
    clicks = 'clicks'
    ctr = 'ctr'
    video_completions = 'video_completions'
    completion_rate = 'completion_rate'
    conversions = 'conversions'
    viewability = 'viewability'
    engagement_rate = 'engagement_rate'
