# generated by datamodel-codegen:
#   filename:  core/assets/video_asset.json
#   timestamp: 2025-11-22T19:16:02+00:00

from __future__ import annotations

from typing import Annotated

from pydantic import AnyUrl, Field

from ..dimensions import Dimensions


class VideoAsset(Dimensions):
    bitrate_kbps: Annotated[
        int | None, Field(description='Video bitrate in kilobits per second', ge=1)
    ] = None
    duration_ms: Annotated[
        int | None, Field(description='Video duration in milliseconds', ge=1)
    ] = None
    format: Annotated[str | None, Field(description='Video file format (mp4, webm, mov, etc.)')] = (
        None
    )
    url: Annotated[AnyUrl, Field(description='URL to the video asset')]
